<?php

namespace B2buy\CareProvider\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\CareProvider\Models\CareProvider;

class CareProviderPolicy
{

    /**
     * Determine if the given user can view the care_provider.
     *
     * @param UserPolicy $user
     * @param CareProvider $care_provider
     *
     * @return bool
     */
    public function view(UserPolicy $user, CareProvider $care_provider)
    {
        if ($user->canDo('care_provider.care_provider.view') && $user->isAdmin()) {
            return true;
        }

        return $care_provider->user_id == user_id() && $care_provider->user_type == user_type();
    }

    /**
     * Determine if the given user can create a care_provider.
     *
     * @param UserPolicy $user
     * @param CareProvider $care_provider
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('care_provider.care_provider.create');
    }

    /**
     * Determine if the given user can update the given care_provider.
     *
     * @param UserPolicy $user
     * @param CareProvider $care_provider
     *
     * @return bool
     */
    public function update(UserPolicy $user, CareProvider $care_provider)
    {
        if ($user->canDo('care_provider.care_provider.edit') && $user->isAdmin()) {
            return true;
        }

        return $care_provider->user_id == user_id() && $care_provider->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given care_provider.
     *
     * @param UserPolicy $user
     * @param CareProvider $care_provider
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CareProvider $care_provider)
    {
        return $care_provider->user_id == user_id() && $care_provider->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given care_provider.
     *
     * @param UserPolicy $user
     * @param CareProvider $care_provider
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CareProvider $care_provider)
    {
        if ($user->canDo('care_provider.care_provider.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given care_provider.
     *
     * @param UserPolicy $user
     * @param CareProvider $care_provider
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CareProvider $care_provider)
    {
        if ($user->canDo('care_provider.care_provider.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
