<?php

namespace B2buy\CareProvider\Providers;

use Illuminate\Support\ServiceProvider;

class CareProviderServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'care_provider');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'care_provider');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCareProvider();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCareProvider()
    {
        $this->app->bind('care_provider', function($app) {
            return new CareProvider($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('CareProvider', 'Lavalite\CareProvider\Facades\CareProvider');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('b2buy.care_provider', function ($app) {
            return $this->app->make('B2buy\CareProvider\CareProvider');
        });

                // Bind CareProvider to repository
        $this->app->bind(
            'B2buy\CareProvider\Interfaces\CareProviderRepositoryInterface',
            \B2buy\CareProvider\Repositories\Eloquent\CareProviderRepository::class
        );

        $this->app->register(\B2buy\CareProvider\Providers\AuthServiceProvider::class);
                $this->app->register(\B2buy\CareProvider\Providers\EventServiceProvider::class);
        
        $this->app->register(\B2buy\CareProvider\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and care_provider's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'b2buy.care_provider'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCareProvider::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['b2buy.care_provider'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('b2buy/care_provider.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/care_provider')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/care_provider')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
